# pl-extension

[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pl-extension)](https://pypi.org/project/pl-extension/) [![PyPI](https://img.shields.io/pypi/v/pl-extension)](https://pypi.org/project/pl-extension) 

`PytorchLightning` is awesome, we love using pl.

`pl-extension` is some useful extensions for pl.

There are many pl-extension-like project:

- [lightning-flash](https://github.com/PyTorchLightning/lightning-flash)
- [lightning-transformers](https://github.com/PyTorchLightning/lightning-transformers)
- [lightning-bolts](https://github.com/PyTorchLightning/lightning-bolts)
